summaryrefslogtreecommitdiff
path: root/deps/v8/src/serialize.h
diff options
context:
space:
mode:
authorRyan <ry@tinyclouds.org>2009-07-20 13:18:42 +0200
committerRyan <ry@tinyclouds.org>2009-07-20 13:18:42 +0200
commit88e9a5f122822b96e0ccfbba2083fe6ef43f3fdc (patch)
tree3cad417de864555fd27d573af866f2a1b3c352ad /deps/v8/src/serialize.h
parentf4dfbe37a3f1fef2c91068958dfe1888ba100332 (diff)
downloadnode-new-88e9a5f122822b96e0ccfbba2083fe6ef43f3fdc.tar.gz
Upgrade V8 to 1.2.14
Diffstat (limited to 'deps/v8/src/serialize.h')
-rw-r--r--deps/v8/src/serialize.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/deps/v8/src/serialize.h b/deps/v8/src/serialize.h
index 7f4eb63216..1b24065cf7 100644
--- a/deps/v8/src/serialize.h
+++ b/deps/v8/src/serialize.h
@@ -320,10 +320,11 @@ class Deserializer: public ObjectVisitor {
bool has_log_; // The file has log information.
// Resolve caches the following:
- List<Page*> map_pages_; // All pages in the map space.
+ List<Page*> map_pages_; // All pages in the map space.
+ List<Page*> cell_pages_; // All pages in the cell space.
List<Page*> old_pointer_pages_; // All pages in the old pointer space.
- List<Page*> old_data_pages_; // All pages in the old data space.
- List<Page*> code_pages_;
+ List<Page*> old_data_pages_; // All pages in the old data space.
+ List<Page*> code_pages_; // All pages in the code space.
List<Object*> large_objects_; // All known large objects.
// A list of global handles at deserialization time.
List<Object**> global_handles_;